import requests
import time
from datetime import datetime as dt

from selenium import webdriver
from selenium.webdriver.common.keys import Keys
from selenium.webdriver.common.by import By
from selenium.common.exceptions import NoAlertPresentException, WebDriverException

from .domain import Maquine
from .utils import raw_data
from .exceptions import ZklibWebNetworkException


class ZkMaquine:
    def __init__(self, maquine: Maquine):
        self._maquine = maquine
        self._driver = webdriver.Firefox()
        self._requests = requests
        self._is_login = False

    def login(self, timeout=1):
        try:
            self._driver.get(self._maquine.get_host())
            username_input = self._driver.find_element_by_name('username')
            password_input = self._driver.find_element_by_name('userpwd')
            username_input.send_keys(self._maquine.username)
            password_input.send_keys(self._maquine.password)
            password_input.send_keys(Keys.ENTER)
            time.sleep(timeout)
            alert = self._driver.switch_to.alert
            alert.accept()
        except NoAlertPresentException:
            self._is_login = True
        except WebDriverException:
            raise ZklibWebNetworkException()
        return self._is_login

    def get_uids(self):
        if not self._is_login:
            raise ValueError('You must call login method first')
        self._driver.get(self._maquine.get_url_for_uids())
        form = self._driver.find_element_by_name('mainform')
        uids = []
        for i in form.find_elements(By.XPATH, '//input[@type=\'checkbox\']'):
            uids.append(i.get_property('value'))
        return uids

    def get_data(self, start_date: dt, end_date: dt):
        data = self._requests.post(self._maquine.get_url_for_download(), data={
            'sdate': start_date.strftime('%Y-%m-%d'),
            'edate': end_date.strftime('%Y-%m-%d'),
            'period': 0,
            'uid': self.get_uids()
        })
        return raw_data(data.text)

    def close(self):
        self._driver.close()
        self._is_login = False
